
********************************************************************************
* Programa de cálculo para la creación de bases auxilares para el MMIP 2022
* Ultima actualización: 31/01/2024
********************************************************************************

********************************************************************
* Contenido del programa
********************************************************************

* 0. Directorios de trabajo
* 1. Creación de la base de uso de tiempo
* 2. Creación de la base de tarifas de energía eléctrica
* 3. Creación de la base de municipios frios/calientes
* 4. Creación de la base de prelación para salud/seguridad social vía ingresos

********************************************************************************

clear all
set more off

********************************************************************************
* 0. Directorios de trabajo
********************************************************************************

gl ruta=      "D:\EVALUA\2022"
gl bases=	  "$ruta/bases"
gl final=	  "$ruta/final"
gl tmp=		  "$ruta/tmp"
gl ajusteCN=  "$ruta/ajusteCN"

********************************************************************************

********************************************************************
* 1. Creación de la base de uso de tiempo
********************************************************************

*Programa de cálculo de imputación al Módulo de uso de Tiempo ENIGH 2022

* 1.1 Variables auxiliares para la imputación 
* 1.2 Imputación de las preguntas de Uso de Tiempo de la ENIGH-2022
*     1.2.1 Trabajar (incluya todo el tiempo dedicado a su trabajo extradoméstico) 
*     1.2.2 Estudiar y hacer actividades relacionadas con el estudio?
*     1.2.3 Realizar trabajo comunitario o voluntario?
*     1.2.4 Cuidar, atender sin pago y de manera exclusiva a niños, ancianos, enfermos, discapacitados?
*     1.2.5 Reparar o dar mantenimiento a su vivienda, muebles, aparatos domésticos o vehículos?
*     1.2.6 Realizar el quehacer de su hogar?
*     1.2.7 Acarrear agua o leña?

********************************************************************************
*1.1 Variables auxiliares para la imputación 
********************************************************************************

********************************************************************************
*Creación de la base de datos necesaria para imputar uso de tiempo
********************************************************************************
*Trabajo 
use "$bases/trabajos.dta", clear
collapse (sum) htrab, by(folioviv foliohog numren)

*Se consideran valores de hasta 98 horas (máximo hipotético posible)
replace htrab=98 if htrab > 98 & htrab <=300
label var htrab "Horas de trabajo del 1 y 2 empleo"

* Horas de trabajo dicotómicas
gen htrab_d = (htrab >= 0 & htrab <= 100)
tab htrab_d
label var htrab_d "Horas de trabajo dicotomica"
count

sort folioviv foliohog numren 
save "$tmp/htrab.dta", replace

*Hogares+vivienda+factor
use "$bases/hogares.dta", clear
merge  m:1 folioviv  using "$bases/viviendas.dta"
drop _merge

egen folio=concat(folioviv foliohog)

drop tam_loc 
merge 1:1 folio using "$final/factexp.dta"
drop _merge
save "$tmp/hog_viv.dta", replace

*Base para imputar uso de tiempo
use "$bases/poblacion.dta", clear

merge m:1 folioviv foliohog numren using "$tmp/htrab.dta"
drop _merge
merge m:1 folioviv foliohog  using "$tmp/hog_viv.dta"
drop _merge

gen auto_d = ( num_auto >= 1 & num_auto <= 100)
gen van_d = ( num_van >= 1 & num_van <= 100)
gen pickup_d = ( num_pickup >= 1 & num_pickup <= 100)
gen moto_d = ( num_moto >= 1 & num_moto <= 100)
gen transporte = auto_d + van_d + pickup_d + moto_d
replace transporte = 1 if transporte >= 1 & transporte <= 100

label var tam_loc "Tamaño de localidad"
label var transporte "Uso de vehiculo en el hogar"


recode htrab htrab_d (.=0) if edad>=12
tab htrab_d [fw=factor] if edad>=12 & htrab_d >= 0.0005 


*Variable dicotómica de 12 años o más
gen mayores12=1 if edad>=12
recode mayores12(.=0)
tab mayores12
tab mayores12 [fw=factor]
label var mayores12 "Población de 12 años o más"

* Grupos de edad
gen grupos_edad=.
replace grupos_edad=1 if edad>=12 & edad<=17
replace grupos_edad=2 if edad>=18 & edad<=69
replace grupos_edad=3 if edad>=70 & edad<=79
replace grupos_edad=4 if edad>=80 & edad<=110

* Etiquetas de grupos de edad
label define edad 1 "12 a 17" ///
                  2 "18 a 69" ///
				  3 "70 a 79" /// 
				  4 "80 o más"
label values grupos_edad edad
label var  grupos_edad "Grupos de edad (mayores de 12)"

* Sexo			 
destring sexo, replace
replace sexo = 0 if sexo == 1
replace sexo = 1 if sexo == 2
label var  sexo "Sexo"

* Etiqueta de sexo
label define sexo 0 "Hombre" ///
                  1 "Mujer" 
label values sex sexo

* Nivel educativo aprobado
gen nivelaprob2 = nivelaprob
destring nivelaprob2, replace
label var nivelaprob2 "Nivel de instrucción aprobado"

* Rural / Urbano
gen urbana=1
replace urbana=0 if tam_loc==4

* Etiqueta de localidad urbana /rural
label define urbana 1 "Urbana" ///
                    0 "Rural"
label value urbana urbana
label var urbana "Tipo de localidad urbana"

* Estratos socioeconómicos
gen est_socio2=est_socio
label var est_socio2 "Estrato socioeconómico"
destring est_socio2, replace

* Personas de 22 años o más
gen mayores22 = 1 if edad >= 22
recode mayores22 (.=0)
label var mayores22 "Personas de 22 años o más"

* Con licenciatura
gen pob_lic=1 if nivelaprob>="7"
recode pob_lic (.=0)
label var pob_lic "Población con nivel profesional y más"


* Estratos socieconómico en 2 categorías 
gen med_alto = 1 if est_socio2 >= 3 & est_socio2 <= 4 & mayores12 ==1
replace med_alto = 0 if est_socio2 >= 1 & est_socio2 <= 2 & mayores12 ==1
tab est_socio2
tab med_alto
label var  med_alto "Estrato socioeconómico bajo o alto"

* Personas con cinco años o menos
gen menores5 = 1 if edad >= 0 & edad <= 5
recode menores5 (.=0)
label var menores5 "Menores de 5 años"


*Menores de 5 en el hogar
egen menores5_h = sum(menores5), by(folioviv foliohog)
recode menores5_h (1/15 = 1)
tab menores5_h
label var menores5 "Menores de 5 años en el hogar"



* Población de 6 a 15 años
gen edad_6a15 = 1 if edad >= 6 & edad <= 15
recode edad_6a15 (.=0)
label var edad_6a15 "Población de 6 a 15 años"

egen edad_6a15_h = sum(edad_6a15), by(folioviv foliohog)
recode edad_6a15_h (1/10 = 1)
tab edad_6a15_h
label var edad_6a15_h "Población de 6 a 15 años en el hogar"


* Construcción de la variable discapacidad 

*Con limitación
gen discap1 = .
replace discap1=0 if disc_camin=="3" | disc_camin=="4"
replace discap1=0 if disc_ver=="3"   | disc_ver=="4"
replace discap1=0 if disc_brazo=="3" | disc_brazo=="4"
replace discap1=0 if disc_apren=="3" | disc_apren=="4"
replace discap1=0 if disc_oir=="3"   | disc_oir=="4"
replace discap1=0 if disc_vest=="3"  | disc_vest=="4"
replace discap1=0 if disc_habla=="3" | disc_habla=="4"
replace discap1=0 if disc_acti=="3"  | disc_acti=="4"


*Con discapacidad
gen discap2=1 if (disc_camin=="1" | disc_camin=="2") 
gen discap3=1 if (disc_ver=="1"   | disc_ver=="2")
gen discap4=1 if (disc_brazo=="1" | disc_brazo=="2")
gen discap5=1 if (disc_apren=="1" | disc_apren=="2")
gen discap6=1 if (disc_oir=="1"   | disc_oir=="2")
gen discap7=1 if (disc_vest=="1"  | disc_vest=="2")
gen discap8=1 if (disc_habla=="1" | disc_habla=="2")
gen discap9=1 if (disc_acti=="1"  | disc_acti=="2")

recode discap*(.=0)

gen sum_discapacidades=discap1+discap2+discap3+discap4+discap5+discap6+discap7+discap8+discap9
label var sum_discapacidades "Población con discapacidad 1 o más"

*Discapacidad
gen discapacidad =.
replace discapacidad =1 if sum_discapacidades >0
tab discapacidad
recode discapacidad (.=0)
label var discapacidad "Población con discapacidad"

*Discapacidad por hogar
egen discap_h = sum(discapacidad), by(folioviv foliohog)
recode discap_h (1/10 = 1)
tab discap_h
label var discap_h "Discapacidad en el hogar"

* Sin menores de 5 pero sí tienen otras poblaciones de cuidado
gen cuidados_h = 1 if menores5_h == 0 & (edad_6a15_h == 1 | discap_h ==1 )
recode cuidados_h (.=0)
tab cuidados_h

* Población que requiere cuidados
gen depen_cuidado = 1 if menores5_h == 1
replace depen_cuidado = 2 if cuidados_h == 1
recode depen_cuidado (.=0)
tab depen_cuidado

label define depen_cuidado 0 "Hogares sin personas de cuidado" ///
                           1 "Hogares con menores de 5 años"   ///
				           2 "Hogares con otras poblaciones de cuidado" 

label values depen_cuidado depen_cuidado
tab depen_cuidado

destring disp_agua, gen(agua_disp)
destring dotac_agua, gen(agua_dot)

* Etiquetas para dotación agua
recode agua_dot (.=999)
label define agua_dot 1 "Diario"                ///
                      2 "Cada tercer día"       ///
					  3 "Dos veces por semana"  /// 
					  4 "Una vez por semana"    ///
					  5 "De vez en cuando"      ///
					  999 "Missing"
label values agua_dot agua_dot


* Dicotómica de cisterna
gen cisterna_d = cisterna
destring cisterna_d, replace
replace cisterna_d = 0 if  cisterna_d == 2

* Dicotómica de disponibilidad 
gen disponi_d = 1 if agua_disp >= 2 & agua_disp <= 7 & mayores12 == 1
replace disponi_d = 0 if agua_disp >= 1 & agua_disp <= 1 & mayores12 == 1
tab agua_disp if mayores12 == 1
tab disponi_d if mayores12 == 1

* Edad mayor a 50
gen edad_50 = (edad >= 50 & edad <= 150)
tab edad_50

save "$tmp\poblacion_uso_tiempo.dta", replace

***************************************************************************************
* 1.2.1 trabajar? (incluya todo el tiempo dedicado a su trabajo extradoméstico)  
***************************************************************************************

use "$tmp\poblacion_uso_tiempo.dta", clear

*Variable original de uso de tiempo de trabajo

*Se construye la variable horas considerando los minutos 
gen hrs1=((hor_1*60)+min_1)/60
gen hor_11=hrs1

*Se consideran valores de hasta 98 horas (máximo hipotético posible)
replace hor_11=98 if hor_11 > 98 & hor_11 <=200

* Horas de trabajo categórica según respuesta 
gen     hor1_d = 1 if hor_11 >= 0 & hor_11 <= 98
replace hor1_d = 777 if hor_11 == .          // Missings
replace hor1_d = 999 if usotiempo1  == "9"   // No lo hizo
replace hor1_d = 888 if usotiempo1  == "8"   // No recuerda
* Etiqueta
label define hor1_d 1 "Con información" ///
                    777 "Missing"       ///
				    888 "No recuerda"   ///
				    999 "No lo hizo"
label values hor1_d hor1_d

tab hor1_d if mayores12 == 1

*Analisis de variables
* Cruce de variables de horas de trabajo (dicotomica) y horas de trabajo (dicotomica)
tab htrab_d hor1_d if mayores12 == 1
tab htrab_d hor1_d if mayores12 == 1 [fw=factor]

*Se identifica aquellas personas con missing y no recuerda y aquellos que reportaron horas de trabajo 
gen pob_trab = ( htrab_d == 1 & (hor1_d == 777 | hor1_d == 888) & mayores12 == 1 )

*Imputación
gen hor1_imputada1=hor_11                         // Valor original
replace hor1_imputada1 = htrab if pob_trab == 1   // Valor imputado

gen imp_1=1 if pob_trab == 1 

label variable hor_11   "Horas de trabajo original (horas y minutos)"
label variable hor1_d   "Horas de trabajo categórica original"
label variable hor1_imputada   "Horas de trabajo (imputación con mediana)"


********************************************************************************
* 1.2.2 Estudiar y hacer actividades relacionadas con el estudio?
********************************************************************************

*Variable original de uso de tiempo de estudio 

*Se construye la variable horas considerando los minutos
gen hrs2=((hor_2*60)+min_2)/60
gen hor_22=hrs2

*Se consideran valores de hasta 98 horas (máximo hipotético posible)
replace hor_22 = 98 if hor_22 > 98 & hor_22 <=200

* Horas de estudio categórica según respuesta
gen hor2_d = 1 if hor_22 >= 0 & hor_22 <= 98   // Con información
replace hor2_d = 777 if hor_22 == .            // Missings
replace hor2_d = 999 if usotiempo2  == "9"     // No lo hizo
replace hor2_d = 888 if usotiempo2  == "8"     // No recuerda

* Etiqueta
label define hor2_d 1 "Con información" ///
                    777 "Missing"       ///
				    888 "No recuerda"   ///
				    999 "No lo hizo"
					
label values hor2_d hor2_d

*Analisis de variables
tab asis_esc hor2_d if mayores12==1
gen pob_est_imp = 1 if  hor2_d == 777 & asis_esc == "1" & mayores12 == 1
tab pob_est_imp

* Estadísticas por mayores de 22 años y menores de 22 y asiste a la escuela
tabstat hor_22 if asis_esc == "1" & (hor_22 >= 0.005 & hor_22 <= 98), stats(mean p50 n) by(mayores22)

*Imputacion
gen hor2_imputada     = hor_22  // Valor original
replace hor2_imputada = 37 if hor2_imputada == . & pob_est_imp == 1 & mayores22 == 0 // Menores 22 & Asisten
replace hor2_imputada = 24 if hor2_imputada == . & pob_est_imp == 1 & mayores22 == 1 // 22 o más & Asisten
gen imp_2=1 if pob_est_imp == 1 

label variable hor_22   "Horas de estudio original (horas y minutos)"
label variable hor2_d   "Horas de estudio categórica original"
label variable hor2_imputada   "Horas de estudio (imputación con mediana)"

********************************************************************************
* 1.2.3 Realizar trabajo comunitario o voluntario?
********************************************************************************

*Variable original de trabajo comunitario

*Se construye la variable horas considerando los minutos 
gen hrs3=((hor_3*60)+min_3)/60
gen hor_33=hrs3 if mayores12==1 

*Se consideran valores de hasta 98 horas (máximo hipotético posible)
replace hor_33 = 98 if hor_33 > 98 & hor_33 <=200

** Horas de trabajo comunitario categorica según respuesta
gen hor3_d = 1 if hor_33 >= 0 & hor_33 <= 98 // con información
replace hor3_d = 777 if hor_33 == .          // Missings
replace hor3_d = 999 if usotiempo3  == "9"   // No lo hizo
replace hor3_d = 888 if usotiempo3  == "8"   // No recuerda

label define hor3_d 1 "Con información" ///
                    777 "Missing"       ///
				    888 "No recuerda"   ///
				    999 "No lo hizo"
label values hor3_d hor3_d

*Analisis de variables
tab  hor3_d if mayores12 == 1
tab est_socio2 if mayores12 == 1 & hor3_d== 1
tab sexo est_socio2 if hor3_d == 1 & mayores12 == 1 , col
*Tasa de respuesta a partir hor3_d
dis ((15203+118)/(15203+118+198933)*36585)

*Identificación de la  población sobre la cual se seleccionara aleatoriamente para imputar a partir de la tasa de respuesta

* Hombres
gen miss_est1_h = 1 if  est_socio2 == 1 & hor3_d == 777 & mayores12 == 1 & sexo == 0
tab miss_est1_h
gen miss_est2_h = 1 if  est_socio2 == 2 & hor3_d == 777 & mayores12 == 1 & sexo == 0
tab miss_est2_h
gen miss_est3_h = 1 if  est_socio2 == 3 & hor3_d == 777 & mayores12 == 1 & sexo == 0
tab miss_est3_h
gen miss_est4_h = 1 if  est_socio2 == 4 & hor3_d == 777 & mayores12 == 1 & sexo == 0
tab miss_est4_h
* Mujeres
gen miss_est1_m = 1 if  est_socio2 == 1 & hor3_d == 777 & mayores12 == 1 & sexo == 1
tab miss_est1_m
gen miss_est2_m = 1 if  est_socio2 == 2 & hor3_d == 777 & mayores12 == 1 & sexo == 1
tab miss_est2_m
gen miss_est3_m = 1 if  est_socio2 == 3 & hor3_d == 777 & mayores12 == 1 & sexo == 1
tab miss_est3_m
gen miss_est4_m = 1 if  est_socio2 == 4 & hor3_d == 777 & mayores12 == 1 & sexo == 1
tab miss_est4_m

*Identificación de la población a imputar según estrato socieconómico y sexo
* Selección de muestra aleatoria a partir de la población que no reportó información 
ssc install randomtag
* Hombres
set seed 12345
randomtag if miss_est1_h == 1, count(501) gen(imp3_1_h)
set seed 12345
randomtag if miss_est2_h == 1, count(529) gen(imp3_2_h)
set seed 12345
randomtag if miss_est3_h == 1, count(133) gen(imp3_3_h)
set seed 12345
randomtag if miss_est4_h == 1, count(61) gen(imp3_4_h)
* Mujeres
set seed 12345
randomtag if miss_est1_m == 1, count(474) gen(imp3_1_m)
set seed 12345
randomtag if miss_est2_m == 1, count(650) gen(imp3_2_m)
set seed 12345
randomtag if miss_est3_m == 1, count(182) gen(imp3_3_m)
set seed 12345
randomtag if miss_est4_m == 1, count(86) gen(imp3_4_m)

* Población seleccionada de manera aleatoria
gen imp3 = imp3_1_h + imp3_2_h + imp3_3_h + imp3_4_h + imp3_1_m + imp3_2_m + imp3_3_m + imp3_4_m
tab imp3
drop imp3_*

* Estadísticas 
sort folioviv foliohog numren 
bysort urbana: tabstat hor_33 if (hor_33 >= 0.005 & hor_33 <= 98), stats( mean p50 n ) by( edad_50)
sort folioviv foliohog numren 

* Imputación de horas de trabajo comunitario a partir de las medianas
gen hor3_imputada  = hor_33  // Variable original
replace hor3_imputada = 4 if hor_33 == . & edad_50 == 0 & urbana == 0 & imp3 == 1 // Rural & Menor a 50
replace hor3_imputada = 4 if hor_33 == . & edad_50 == 1 & urbana == 0 & imp3 == 1 // Rural & Mayor a 50
replace hor3_imputada = 4 if hor_33 == . & edad_50 == 0 & urbana == 1 & imp3 == 1 // Urbana & Menor a 50
replace hor3_imputada = 6 if hor_33 == . & edad_50 == 1 & urbana == 1 & imp3 == 1 // Urbana & Mayor a 50

* Etiquetas
label variable hor_33   "Horas de trabajo comunitario original (horas y minutos)"
label variable hor3_d   "Horas de trabajo comunitario categórica original"
label variable hor3_imputada   "Horas de trabajo comunitario (imputación con mediana)"

********************************************************************************
* 1.2.4  Cuidar, atender sin pago y de manera exclusiva a niños, ancianos, enfermos, discapacitados?
********************************************************************************

*Variable original de cuidado

* Se construye la variable horas considerando los minutos
gen hrs4=((hor_4*60)+min_4)/60
gen hor_44=hrs4 if mayores12==1 

*Se consideran valores de hasta 98 horas (máximo hipotético posible)
replace hor_44 = 98 if hor_44 > 98 & hor_44 <=200

* Horas para reparar o dar mantenimiento a su vivienda según respuesta
gen hor4_d = 1 if hor_44 >= 0 & hor_44 <= 98 // con información 
replace hor4_d = 777 if hor_44 == .          // Missings
replace hor4_d = 999 if usotiempo4  == "9"   // No lo hizo
replace hor4_d = 888 if usotiempo4  == "8"   // No recuerda

* * Horas de cuidado categórica según respuesta
label define hor4_d 1 "Con información" ///
                    777 "Missing"       ///
				    888 "No recuerda"   ///
				    999 "No lo hizo"
label values hor4_d hor4_d

*Analisis de variables
tab sexo hor4_d  if mayores12 == 1
*Tasa de respuesta a partir hor4_d
*Hombres
dis ((17896+74)/(17896+74+79070)*22365)
*Mujeres
dis ((37555+83)/(37555+83+79576)*14220)

*Identificación de la  población sobre la cual se seleccionara aleatoriamente
* Hombres
gen cuidado_h = 1 if hor4_d == 777 & mayores12 == 1 & sexo == 0
tab cuidado_h
* Mujeres
gen cuidado_m = 1 if hor4_d == 777 & mayores12 == 1 & sexo == 1
tab cuidado_m

*identificación de la poblacion a imputar
* Selección aleatoria proporcional al tamaño de sexo
set seed 12345
randomtag if cuidado_h == 1, count(4142) gen(imp4_h)
set seed 12345
randomtag if cuidado_m == 1, count(4566) gen(imp4_m)
* Población seleccionada de manera aleatoria
gen imp4 = imp4_h + imp4_m
drop imp4_*

* Estadísticas a nivel de tipo de dependientes
tabstat hor_44 if mayores12 == 1 & hor4_d == 1 , stats(mean p50 n) by(depen_cuidado)

* Imputacion de horas de traba comunitario a partir de las medianas x la variable de cuidados
gen hor4_imputada = hor_44 //Variable original
replace hor4_imputada = 14 if hor_44 == . & depen_cuidado == 0 & imp4 == 1 // Sin dependientes
replace hor4_imputada = 20 if hor_44 == . & depen_cuidado == 1 & imp4 == 1 // Con menores de 5
replace hor4_imputada = 15 if hor_44 == . & depen_cuidado == 2 & imp4 == 1 // Otros dependientes

* Etiquetas
label variable hor_44   "Horas de cuidado original (horas y minutos)"
label variable hor4_d   "Horas de cuidado categórica original"
label variable hor4_imputada   "Horas de cuidado (imputación con mediana)"

********************************************************************************
* 1.2.5 Reparar o dar mantenimiento a su vivienda, muebles, aparatos domésticos o vehículos?
********************************************************************************

*Variable original de eparar o dar mantenimiento a su vivienda
*Se construye la variable horas considerando los minutos
gen hrs5=((hor_5*60)+min_5)/60
gen hor_55=hrs5 if mayores12==1 

* se consideran valores de hasta 98 horas (Máximo hipotético posible)
replace hor_55 = 98 if hor_55 > 98 & hor_55 <=200

* Horas para reparar o dar mantenimiento a su vivienda categórica según respuesta
gen hor5_d = 1 if hor_55 >= 0 & hor_55 <= 98 // Con información
replace hor5_d = 777 if hor_55 == .          // Missings
replace hor5_d = 999 if usotiempo5  == "9"   // No lo hizo
replace hor5_d = 888 if usotiempo5  == "8"   // No recuerda

* Etiqueta
label define hor5_d   1 "Con información" ///
                    777 "Missing"         ///
				    888 "No recuerda"     ///
				    999 "No lo hizo"
					
label values hor5_d hor5_d

*Analisis de variables
* Tablas de frecuencia sexo Vs horas de mantenimiento
tab  sexo  hor5_d if mayores12 == 1
*Tasa de respuesta a partir hor5_d
*Hombres
dis ((32671+63)/(32671+63+64306)*22365)
*Mujeres
dis ((10078+60)/(10078+60+107076)*14220)

* *Identificación de la población con missing por sexo y mayores 12
* Hombres
gen mante_h = 1 if hor5_d == 777 & mayores12 == 1 & sexo == 0
* Mujeres
gen mante_m = 1 if hor5_d == 777 & mayores12 == 1 & sexo == 1

*identificación de la poblacion a imputar
* Selección aleatoria proporcional al tamaño de sexo
set seed 12345
randomtag if mante_h == 1, count(7544) gen(imp5_h)
set seed 12345
randomtag if mante_m == 1, count(1230) gen(imp5_m)

* Población seleccionada de manera aleatoria
gen imp5 = imp5_h + imp5_m
tab sexo imp5
drop imp5_*

* Estadísticas por estratos y sexo
sort folioviv foliohog numren 
bysort sexo: tabstat hor_55 if mayores12 == 1 & hor5_d == 1, stats(mean p50 n) by(est_socio2)
sort folioviv foliohog numren 

* Imputar mediana por estratos socioeconómico y sexo
gen hor5_imputada = hor_55 // Variable original
* Hombres
replace hor5_imputada = 5 if hor_55 == . & sexo == 0 & est_socio2 == 1 & imp5 == 1 // Hombres y estrato socieconómico 1
replace hor5_imputada = 5 if hor_55 == . & sexo == 0 & est_socio2 == 2 & imp5 == 1 // Hombres y estrato socieconómico 2
replace hor5_imputada = 5 if hor_55 == . & sexo == 0 & est_socio2 == 3 & imp5 == 1 // Hombres y estrato socieconómico 3
replace hor5_imputada = 4 if hor_55 == . & sexo == 0 & est_socio2 == 4 & imp5 == 1 // Hombres y estrato socieconómico 4
* Mujeres
replace hor5_imputada = 3 if hor_55 == . & sexo == 1 & est_socio2 == 1 & imp5 == 1 // Mujeres y estrato socieconómico 1
replace hor5_imputada = 4 if hor_55 == . & sexo == 1 & est_socio2 == 2 & imp5 == 1 // Mujeres y estrato socieconómico 2
replace hor5_imputada = 4 if hor_55 == . & sexo == 1 & est_socio2 == 3 & imp5 == 1 // Mujeres y estrato socieconómico 3
replace hor5_imputada = 4 if hor_55 == . & sexo == 1 & est_socio2 == 4 & imp5 == 1 // Mujeres y estrato socieconómico 4
* Etiquetas
label variable hor_55   "Horas de mantenimiento original (horas y minutos)"
label variable hor5_d   "Horas de mantenimiento categórica original"
label variable hor5_imputada   "Horas de mantenimiento (imputación con mediana)"

********************************************************************************
* 1.2.6 Realizar el quehacer de su hogar?
********************************************************************************

*Variable original de quehacer en el hogar

*Se construye la variable horas considerando los minutos
gen hrs6=((hor_6*60)+min_6)/60
gen hor_66=hrs6 if mayores12==1 
* Se consideran valores de hasta 98 horas (Máximo hipotético posible)
replace hor_66 = 98 if hor_66 > 98 & hor_66 <=200

*Horas para realizar quehaceres en el hogar categórica según respuesta
gen hor6_d = 1 if hor_66 >= 0 & hor_66 <= 98 // Con información
replace hor6_d = 777 if hor_66 == .          // Missings
replace hor6_d = 999 if usotiempo6  == "9"   // No lo hizo
replace hor6_d = 888 if usotiempo6  == "8"   // No recuerda

* Horas de quehacer categórica según respuesta
label define hor6_d   1 "Con información" ///
                    777 "Missing"         ///
				    888 "No recuerda"     ///
				    999 "No lo hizo"
label values hor6_d hor6_d

*Analisis de variables
tab sexo hor6_d  if mayores12 == 1 
*Tasa de respuesta a partir hor6_d
*Hombres
dis ((63009+86)/(63009+86+33945)*22365)
*Mujeres
dis ((109783+69)/(109783+69+7362)*14220)
* Variable auxiliar que identifica a la población con horas de trabajo (Reportó e imputados)
gen trabajo = 1 if mayores12 == 1 & hor1_imputada1 >0 & hor1_imputada1  <=98
recode trabajo (.=0)


*Identificación de la población con missing por sexo y mayores 12
* Hombres
gen quehacer_h = 1 if hor6_d == 777 & mayores12 == 1 & sexo == 0
* Mujeres
gen quehacer_m = 1 if hor6_d == 777 & mayores12 == 1 & sexo == 1

* Selección aleatoria proporcional al tamaño de sexo
set seed 12345
randomtag if quehacer_h == 1, count(14542) gen(imp6_h)
set seed 12345
randomtag if quehacer_m == 1, count(13327) gen(imp6_m)

* Población seleccionada de manera aleatoria
gen imp6 = imp6_h + imp6_m
tab sexo imp6
drop imp6_*

* Estadísticas por sexo de horas reportadas de quehacer del hogar por condición laboral
sort folioviv foliohog numren sexo
bysort sexo: tabstat hor_66 if mayores12 == 1 & hor6_d==1 , stats(mean p50 n) by(trabajo) 
sort folioviv foliohog numren sexo

* Imputar mediana por sexo
gen hor6_imputada  = hor_66 // variable original

replace hor6_imputada =  7 if hor_66 == . & sexo == 0 & trabajo  == 0 & imp6==1 // Hombres y No trabajo
replace hor6_imputada =  7 if hor_66 == . & sexo == 0 & trabajo  == 1 & imp6==1 // Hombres y Sí trabajo
replace hor6_imputada = 21 if hor_66 == . & sexo == 1 & trabajo  == 0 & imp6==1 // Mujeres y No trabajo
replace hor6_imputada = 14 if hor_66 == . & sexo == 1 & trabajo  == 1 & imp6==1 // Mujeres y Sí trabajo

* Etiquetas
label variable hor_66        "Horas de cuidado original (horas y minutos)"
label variable hor6_d        "Horas de cuidado categórica original"
label variable hor6_imputada "Horas de cuidado (imputación con mediana)"

********************************************************************************
* 1.2.7  Acarrear agua o leña?
********************************************************************************
*Variable original por acarrear agua o leña
*Se construye la variable horas considerando los minutos 
gen hrs7=((hor_7*60)+min_7)/60
gen hor_77=hrs7 if mayores12==1 

* Se consideran valores de hasta 98 horas (máximo hipotético posible)
replace hor_77 = 98 if hor_77 > 98 & hor_77 <=200

* Horas de acarreo categórica según respuesta
gen hor7_d = 1 if hor_77 >= 0 & hor_77 <= 98 // Con información
replace hor7_d = 777 if hor_77 == .          // Missings
replace hor7_d = 999 if usotiempo7  == "9"   // No lo hizo
replace hor7_d = 888 if usotiempo7  == "8"   // No recuerda

label define hor7_d   1 "Con información"    ///
                    777 "Missing"            ///
				    888 "No recuerda"        ///
				    999 "No lo hizo"
label values hor7_d hor7_d

*Analisis de variables
*Tasa de respuesta a partir hor6_d
tab cisterna hor7_d  if mayores12 == 1 
dis ((28409)/(28409+104+185741)*36585)

* Población sobre la cual se seleccionara aleatoriamente
gen miss_cist1 = 1 if  cisterna == "1" & hor7_d == 777 & mayores12 == 1
gen miss_cist2 = 1 if  cisterna == "2" & hor7_d == 777 & mayores12 == 1

tab miss_cist1
tab miss_cist2

* Selección aleatoria 
set seed 12345
randomtag if miss_cist1 == 1, count(483) gen(imp7_1)
set seed 12345
randomtag if miss_cist2 == 1, count(4368) gen(imp7_2)

* Población seleccionada de manera aleatoria
gen imp7 = imp7_1
replace imp7 = imp7_2 if imp7 == 0
tab imp7
drop imp7_1 imp7_2

* Estadísticas según condición de cisterna
tabstat hor_77 if hor_77 >= 0.005 & hor_77 <= 98, stats(mean p50 n) by(disponi_d )

* Imputación de Horas de acarreo 
gen hor7_imputada  = hor_77 // variable original

replace hor7_imputada = 4 if hor_77 == . & disponi_d == 0 & imp7==1
replace hor7_imputada = 4 if hor_77 == . & disponi_d == 1 & imp7==1

label variable hor_77        "Horas de acarreo de agua o leña original (horas y minutos)"
label variable hor7_d        "Horas de acarreo de agua o leña categórica original"
label variable hor7_imputada "Horas de acarreo de agua o leña (imputación con mediana)"

gen hrs1_imp=hor1_imputada
gen hrs2_imp=hor2_imputada
gen hrs3_imp=hor3_imputada
gen hrs4_imp=hor4_imputada
gen hrs5_imp=hor5_imputada
gen hrs6_imp=hor6_imputada
gen hrs7_imp=hor7_imputada

recode hrs1_imp hrs2_imp hrs3_imp hrs4_imp hrs5_imp hrs6_imp hrs7_imp (.=0) if mayores12==1
tabstat hrs1_imp hrs2_imp hrs3_imp hrs4_imp hrs5_imp hrs6_imp hrs7_imp if mayores12==1, stat (mean P50 sum )


* Depuración de la base de datos 
keep folio numren hor_11 hor_22 hor_33 hor_44 hor_55 hor_66 hor_77 factor  hrs1_imp - hrs7_imp

label variable hrs1_imp   "Horas de trabajo imputado (horas y minutos)"
label variable hrs2_imp   "Horas de estudio imputado (horas y minutos)"
label variable hrs3_imp   "Horas de trabajo comunitario imputado (horas y minutos)"
label variable hrs4_imp   "Horas de cuidado imputado (horas y minutos)"
label variable hrs5_imp   "Horas de mantenimiento imputado (horas y minutos)"
label variable hrs6_imp   "Horas de quehaceres del hogar imputado (horas y minutos)"
label variable hrs7_imp   "Horas de acarreo de agua o leña imputado (horas y minutos)"

gen horas_tot=hrs1_imp+hrs2_imp+hrs3_imp+hrs4_imp+hrs5_imp+hrs6_imp+hrs7_imp

gen horas_tot_agrup=.

replace horas_tot_agrup=0 if horas_tot==0
replace horas_tot_agrup=1 if horas_tot>=.01666667  & horas_tot<=10
replace horas_tot_agrup=2 if horas_tot>10 & horas_tot<=20
replace horas_tot_agrup=3 if horas_tot>20 & horas_tot<=30
replace horas_tot_agrup=4 if horas_tot>30 & horas_tot<=40
replace horas_tot_agrup=5 if horas_tot>40 & horas_tot<=50
replace horas_tot_agrup=6 if horas_tot>50 & horas_tot<=60
replace horas_tot_agrup=7 if horas_tot>60 & horas_tot<=70
replace horas_tot_agrup=8 if horas_tot>70 & horas_tot<=80
replace horas_tot_agrup=9 if horas_tot>80 & horas_tot<=98
replace horas_tot_agrup=10 if horas_tot>98 & horas_tot<=500

label define horas_tot_agrup 0 "0 horas" 1 "menos de 1 a 10 hr" 2 "más de 10 a 20 hr" 3 "más de 20 a 30 hr"            ///
                             4 "más de 30 a 40 hr" 5 "más de 40 a 50 hr"  6 "más de 50 a 60 hr" 7 "más de 60 a 70 hr"  ///
							 8 "más de 70 a 80 hr" 9 "más de 80 a 98 hr" 10 "más de 98 hr"
label value horas_tot_agrup horas_tot_agrup


save "$tmp/imputado_tiempo.dta", replace


********************************************************************
* 2. Creación de la base de tarifas de energía eléctrica
********************************************************************

* Base de datos
clear all
import excel "$bases\Base de datos general_CFE.xlsx", sheet("final") firstrow

* Generar folio de estados y municipios
gen str2 estado = string(CveInegi,"%02.0f")
gen str3 Mun = string(CveMun,"%03.0f")
egen cve_mun=concat(estado Mun)

* Consumo a nivel de hogar
egen total_con=total(year_2017_consumo), by(cve_mun)

* Ordernar base
sort cve_mun
bysort cve_mun: gen por_consumo = year_2017_consumo / total_con
gsort cve_mun -por_consumo

* Colapsar base de datos
collapse (max) por_consumo (first) Tarifa, by(cve_mun)
recode por_consumo (.=0)

* Generar variable de tarifa
gen tarifa_1=1 if Tarifa=="1"
gen tarifa_1A=1 if Tarifa=="1A"
gen tarifa_1B=1 if Tarifa=="1B"
gen tarifa_1C=1 if Tarifa=="1C"
gen tarifa_1D=1 if Tarifa=="1D"
gen tarifa_1E=1 if Tarifa=="1E"
gen tarifa_1F=1 if Tarifa=="1F"
replace tarifa_1F=1 if Tarifa=="DAC"

label variable cve_mun   "Clave municipal"
label variable por_consumo   "Porcentaje de energía eléctrica más común en el municipio"
label variable Tarifa   "Tarifa de energía eléctrica más común en el municipio"
label variable tarifa_1   "Tarifa 1 conforme a la CFE"
label variable tarifa_1A   "Tarifa 1A conforme a la CFE"
label variable tarifa_1B   "Tarifa 1B conforme a la CFE"
label variable tarifa_1C   "Tarifa 1C conforme a la CFE"
label variable tarifa_1D   "Tarifa 1D conforme a la CFE"
label variable tarifa_1E   "Tarifa 1E conforme a la CFE"
label variable tarifa_1F   "Tarifa 1F conforme a la CFE"

save "$bases/tarifas_mun.dta", replace

********************************************************************
* 3. Creación de la base de municipios frios/calientes
********************************************************************

* Abrir base de datos
use "$bases/tarifas_mun.dta", clear

* Genrar variable de ubicación geográfica
gen cve_mun2=cve_mun
destring cve_mun2, replace
label var cve_mun2 "Clave municipal (destring)"


gen mun_frio=.
			
replace mun_frio=1 if   cve_mun2==1001	| cve_mun2==1002	| cve_mun2==1003	| cve_mun2==1004	| cve_mun2==1005	 ///
                      | cve_mun2==1006	| cve_mun2==1007	| cve_mun2==1008	| cve_mun2==1009	| cve_mun2==1010	| cve_mun2==1011	 ///
                      | cve_mun2==2001	| cve_mun2==2002	| cve_mun2==2003	| cve_mun2==2004	| cve_mun2==3001	| cve_mun2==3003	 ///
                      | cve_mun2==3008	| cve_mun2==3009	| cve_mun2==5004	| cve_mun2==5006	| cve_mun2==5007	| cve_mun2==5009	 ///
                      | cve_mun2==5014	| cve_mun2==5017	| cve_mun2==5018	| cve_mun2==5020	| cve_mun2==5024	| cve_mun2==5027	 ///
                      | cve_mun2==5028	| cve_mun2==5030	| cve_mun2==5031	| cve_mun2==5033	| cve_mun2==5035	| cve_mun2==5036	 /// 
                      | cve_mun2==6003	| cve_mun2==7004	| cve_mun2==7019	| cve_mun2==7041	| cve_mun2==7052	| cve_mun2==7059	 ///
                      | cve_mun2==7061	| cve_mun2==7064	| cve_mun2==7078	| cve_mun2==7099	| cve_mun2==7101	| cve_mun2==8001	 ///
                      | cve_mun2==8002	| cve_mun2==8003	| cve_mun2==8005	| cve_mun2==8006	| cve_mun2==8007	| cve_mun2==8008	 ///
                      | cve_mun2==8009	| cve_mun2==8010	| cve_mun2==8011	| cve_mun2==8012	| cve_mun2==8014	| cve_mun2==8017	 ///
                      | cve_mun2==8019	| cve_mun2==8020	| cve_mun2==8021	| cve_mun2==8023	| cve_mun2==8027	| cve_mun2==8028	 ///
                      | cve_mun2==8029	| cve_mun2==8031	| cve_mun2==8032	| cve_mun2==8034	| cve_mun2==8035	| cve_mun2==8036	 ///
                      | cve_mun2==8037	| cve_mun2==8038	| cve_mun2==8039	| cve_mun2==8040	| cve_mun2==8043	| cve_mun2==8045	 ///
                      | cve_mun2==8047	| cve_mun2==8048	| cve_mun2==8050	| cve_mun2==8051	| cve_mun2==8052	| cve_mun2==8054	 ///
                      | cve_mun2==8055	| cve_mun2==8062	| cve_mun2==8063	| cve_mun2==8065	| cve_mun2==8067	| cve_mun2==9002	 ///
                      | cve_mun2==9003	| cve_mun2==9004	| cve_mun2==9005	| cve_mun2==9006	| cve_mun2==9007	| cve_mun2==9008	 ///
					  | cve_mun2==9009  | cve_mun2==9010    | cve_mun2==9011    | cve_mun2==9012    | cve_mun2==9013    | cve_mun2==9014    ///
                      | cve_mun2==9015	| cve_mun2==9016	| cve_mun2==9017	| cve_mun2==10001	| cve_mun2==10003	| cve_mun2==10004	 ///
                      | cve_mun2==10005 | cve_mun2==10006	| cve_mun2==10008	| cve_mun2==10012	| cve_mun2==10013	| cve_mun2==10014	 ///
                      | cve_mun2==10015 | cve_mun2==10016	| cve_mun2==10018	| cve_mun2==10020	| cve_mun2==10021	| cve_mun2==10022	 ///
                      | cve_mun2==10023 | cve_mun2==10027	| cve_mun2==10028	| cve_mun2==10032	| cve_mun2==10033	| cve_mun2==10035	 ///
                      | cve_mun2==10038 | cve_mun2==10039	| cve_mun2==11001	| cve_mun2==11002	| cve_mun2==11003	| cve_mun2==11004	 ///
                      | cve_mun2==11005 | cve_mun2==11007	| cve_mun2==11008	| cve_mun2==11009	| cve_mun2==11011	| cve_mun2==11013	 ///
                      | cve_mun2==11014 | cve_mun2==11015	| cve_mun2==11017	| cve_mun2==11019	| cve_mun2==11020	| cve_mun2==11022	 ///
                      | cve_mun2==11023 | cve_mun2==11024	| cve_mun2==11025	| cve_mun2==11026	| cve_mun2==11027	| cve_mun2==11028	 ///
                      | cve_mun2==11029 | cve_mun2==11030	| cve_mun2==11031	| cve_mun2==11032	| cve_mun2==11033	| cve_mun2==11034	 ///
                      | cve_mun2==11035 | cve_mun2==11036	| cve_mun2==11037	| cve_mun2==11039	| cve_mun2==11042	| cve_mun2==11044	 ///
                      | cve_mun2==11046 | cve_mun2==12028	| cve_mun2==12029	| cve_mun2==12044	| cve_mun2==12072	| cve_mun2==13001	 ///
                      | cve_mun2==13003 | cve_mun2==13004	| cve_mun2==13007	| cve_mun2==13015	| cve_mun2==13016	| cve_mun2==13017	 ///
                      | cve_mun2==13022 | cve_mun2==13025	| cve_mun2==13029	| cve_mun2==13030	| cve_mun2==13036	| cve_mun2==13041	 ///
                      | cve_mun2==13048 | cve_mun2==13050	| cve_mun2==13055	| cve_mun2==13056	| cve_mun2==13058	| cve_mun2==13059	 /// 
                      | cve_mun2==13061 | cve_mun2==13063	| cve_mun2==13067	| cve_mun2==13069	| cve_mun2==13073	| cve_mun2==13076	 /// 
                      | cve_mun2==13081 | cve_mun2==13082	| cve_mun2==13083	| cve_mun2==14003	| cve_mun2==14006	| cve_mun2==14008	 ///
                      | cve_mun2==14009 | cve_mun2==14011	| cve_mun2==14013	| cve_mun2==14016	| cve_mun2==14023	| cve_mun2==14027	 ///
                      | cve_mun2==14030 | cve_mun2==14035	| cve_mun2==14038	| cve_mun2==14039	| cve_mun2==14044	| cve_mun2==14045	 ///
                      | cve_mun2==14046 | cve_mun2==14047	| cve_mun2==14050	| cve_mun2==14053	| cve_mun2==14059	| cve_mun2==14060	 ///
                      | cve_mun2==14063 | cve_mun2==14064	| cve_mun2==14066	| cve_mun2==14069	| cve_mun2==14070	| cve_mun2==14073	 
					  
					  
replace mun_frio=1 if  cve_mun2==14083 | cve_mun2==14093	| cve_mun2==14097	| cve_mun2==14098	| cve_mun2==14105	| cve_mun2==14109	 ///
                      | cve_mun2==14116 | cve_mun2==14120	| cve_mun2==14124	| cve_mun2==15001	| cve_mun2==15003	| cve_mun2==15005	 ///
                      | cve_mun2==15007 | cve_mun2==15010	| cve_mun2==15011	| cve_mun2==15013	| cve_mun2==15014	| cve_mun2==15021	 ///
                      | cve_mun2==15024 | cve_mun2==15025	| cve_mun2==15026	| cve_mun2==15031	| cve_mun2==15032	| cve_mun2==15033	 ///
                      | cve_mun2==15035 | cve_mun2==15037	| cve_mun2==15039	| cve_mun2==15040	| cve_mun2==15046	| cve_mun2==15047	 ///
                      | cve_mun2==15051 | cve_mun2==15052	| cve_mun2==15054	| cve_mun2==15057	| cve_mun2==15059	| cve_mun2==15060	 ///
                      | cve_mun2==15063 | cve_mun2==15064	| cve_mun2==15067	| cve_mun2==15070	| cve_mun2==15074	| cve_mun2==15077	 ///
                      | cve_mun2==15081 | cve_mun2==15084	| cve_mun2==15085	| cve_mun2==15087	| cve_mun2==15088	| cve_mun2==15090	 ///
                      | cve_mun2==15091 | cve_mun2==15099	| cve_mun2==15101	| cve_mun2==15106	| cve_mun2==15108	| cve_mun2==15109	 ///
                      | cve_mun2==15111 | cve_mun2==15112	| cve_mun2==15114	| cve_mun2==15115	| cve_mun2==15118	| cve_mun2==15120	 ///
                      | cve_mun2==16003 | cve_mun2==16018	| cve_mun2==16020	| cve_mun2==16031	| cve_mun2==16041	| cve_mun2==16043	 ///
                      | cve_mun2==16049 | cve_mun2==16050	| cve_mun2==16053	| cve_mun2==16066	| cve_mun2==16068	| cve_mun2==16069	 ///
                      | cve_mun2==16071 | cve_mun2==16073	| cve_mun2==16076	| cve_mun2==16082	| cve_mun2==16085	| cve_mun2==16088	 ///
                      | cve_mun2==16102 | cve_mun2==16105	| cve_mun2==16106	| cve_mun2==16107	| cve_mun2==16108	| cve_mun2==16112	 /// 
                      | cve_mun2==17004 | cve_mun2==17009	| cve_mun2==17016	| cve_mun2==17020	| cve_mun2==17027	| cve_mun2==17030	 ///
                      | cve_mun2==18006 | cve_mun2==18014	| cve_mun2==18017	| cve_mun2==18019	| cve_mun2==19004	| cve_mun2==19005	 ///
                      | cve_mun2==19006 | cve_mun2==19007	| cve_mun2==19009	| cve_mun2==19014	| cve_mun2==19016	| cve_mun2==19017	 ///
                      | cve_mun2==19018 | cve_mun2==19022	| cve_mun2==19023	| cve_mun2==19027	| cve_mun2==19033	| cve_mun2==19034	 ///
                      | cve_mun2==19036 | cve_mun2==19038	| cve_mun2==19039	| cve_mun2==19041	| cve_mun2==19042	| cve_mun2==19045	 ///
                      | cve_mun2==19049 | cve_mun2==19050	| cve_mun2==20016	| cve_mun2==20026	| cve_mun2==20039	| cve_mun2==20041	 ///
                      | cve_mun2==20059 | cve_mun2==20067	| cve_mun2==20073	| cve_mun2==20105	| cve_mun2==20348	| cve_mun2==20394	 ///
                      | cve_mun2==20397 | cve_mun2==20406	| cve_mun2==20418	| cve_mun2==20469	| cve_mun2==20551	| cve_mun2==20570	 /// 
                      | cve_mun2==21004 | cve_mun2==21008	| cve_mun2==21019	| cve_mun2==21053	| cve_mun2==21054	| cve_mun2==21074	 ///
                      | cve_mun2==21083 | cve_mun2==21094	| cve_mun2==21099	| cve_mun2==21110	| cve_mun2==21132	| cve_mun2==21153	 ///
                      | cve_mun2==21154 | cve_mun2==21156	| cve_mun2==21164	| cve_mun2==21169	| cve_mun2==21170	| cve_mun2==21174	 ///
                      | cve_mun2==21179 | cve_mun2==21186	| cve_mun2==21197	| cve_mun2==22001	| cve_mun2==22004	| cve_mun2==22005	 ///
                      | cve_mun2==22006 | cve_mun2==22007	| cve_mun2==22008	| cve_mun2==22010	| cve_mun2==22011	| cve_mun2==22012	 ///
                      | cve_mun2==22013 | cve_mun2==22014	| cve_mun2==22017	| cve_mun2==22018	| cve_mun2==24005	| cve_mun2==24006	 ///
                      | cve_mun2==24010 | cve_mun2==24011	| cve_mun2==24013	| cve_mun2==24017	| cve_mun2==24020	| cve_mun2==24021	 ///
                      | cve_mun2==24023 | cve_mun2==24024	| cve_mun2==24025	| cve_mun2==24028	| cve_mun2==24032	| cve_mun2==24033	 ///
                      | cve_mun2==24035 | cve_mun2==24046	| cve_mun2==24049	| cve_mun2==24050	| cve_mun2==24054	| cve_mun2==24058	 ///
                      | cve_mun2==25001 | cve_mun2==25004	| cve_mun2==25007	| cve_mun2==25010	| cve_mun2==25017	| cve_mun2==26002	 ///
                      | cve_mun2==26003 | cve_mun2==26008	| cve_mun2==26009	| cve_mun2==26018	| cve_mun2==26019	| cve_mun2==26026	 ///
                      | cve_mun2==26027 | cve_mun2==26029	| cve_mun2==26030	| cve_mun2==26033	| cve_mun2==26035	| cve_mun2==26036	 ///
                      | cve_mun2==26042 | cve_mun2==26043	| cve_mun2==26051	| cve_mun2==26055	| cve_mun2==26057	| cve_mun2==26067	 ///
                      | cve_mun2==26069 | cve_mun2==28002	| cve_mun2==28004	| cve_mun2==28008	| cve_mun2==28013	| cve_mun2==28017	 ///
                      | cve_mun2==28018 | cve_mun2==28023	| cve_mun2==28027	| cve_mun2==28029	| cve_mun2==28031	| cve_mun2==28032	 /// 
                      | cve_mun2==28033 | cve_mun2==28036	| cve_mun2==28037	| cve_mun2==28039	| cve_mun2==28041	| cve_mun2==29001	 ///
                      | cve_mun2==29003 | cve_mun2==29004	| cve_mun2==29005	| cve_mun2==29006	| cve_mun2==29008	| cve_mun2==29013	 ///
                      | cve_mun2==29014 | cve_mun2==29015	| cve_mun2==29021	| cve_mun2==29030	| cve_mun2==29031	| cve_mun2==29033	 ///
                      | cve_mun2==29034 | cve_mun2==29035	| cve_mun2==29037	| cve_mun2==29045	| cve_mun2==29046	| cve_mun2==29047	 ///
                      | cve_mun2==30006 | cve_mun2==30023	| cve_mun2==30038	| cve_mun2==30047	| cve_mun2==30065	| cve_mun2==30068	 ///
                      | cve_mun2==30071 | cve_mun2==30079	| cve_mun2==30086	| cve_mun2==30087	| cve_mun2==30118	| cve_mun2==30128	 ///
                      | cve_mun2==30164 | cve_mun2==30188	| cve_mun2==30201	| cve_mun2==32005	| cve_mun2==32006	| cve_mun2==32009	 ///
                      | cve_mun2==32010 | cve_mun2==32011	| cve_mun2==32014	| cve_mun2==32017	| cve_mun2==32019	| cve_mun2==32020	 ///
                      | cve_mun2==32022 | cve_mun2==32023	| cve_mun2==32024	| cve_mun2==32026	| cve_mun2==32031	| cve_mun2==32034   ///
                      | cve_mun2==32035 | cve_mun2==32036	| cve_mun2==32038	| cve_mun2==32039	| cve_mun2==32040	| cve_mun2==32041	 ///
                      | cve_mun2==32042 | cve_mun2==32044	| cve_mun2==32048	| cve_mun2==32049	| cve_mun2==32051	| cve_mun2==32052	 ///
                      | cve_mun2==32053 | cve_mun2==32054	| cve_mun2==32055	| cve_mun2==32056	


label var mun_frio "Municipios en donde los hogares requieren calefacción"
recode mun_frio (.=0)

* Guardar base final de municipios frios/calientes
save "$bases/tarifas_mun.dta", replace


********************************************************************
* 4. Creación de la base de prelación para salud y seguridad social vía ingresos
********************************************************************

*******************************************************************************
* Base de población
*******************************************************************************

* Generar la base de población para unirse a la anterior de pensiones
use "$bases/poblacion.dta", clear

* Se genera la variable folio
egen folio= concat(folioviv foliohog)
sort folio numren 
   
*******************************************************************************
* Base de ingresos monetarios
*******************************************************************************

merge m:1 folio numren using "$ajusteCN/Ing_PC_2022.dta"
drop _merge
merge 1:1 folio numren using "$ajusteCN/ingresos_negocios_p.dta"
recode Y_AGRO_con_coop Y_NO_AGRO_con_coop (.=0)
drop _merge

* Se eliminan los que no son miembros de la familia en el hogar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <800

* Parentescos
recode parentesco   /// 
       (101 102=1)  ///
	   (200/205=2)  ///
	   (300/305=3)  ///
	   (601=4)      ///
	   (615=5)      ///
	   (609=6)      ///    
	   (617=7)      ///
	   (else=0),    ///
	   gen (paren1) 
	   
* Ingresos por trabajo subordinado
gen double remu_asala= remuneraciones 

* Ingresos por trabajo independiente
gen double rent_empre=Y_AGRO_con_coop+Y_NO_AGRO_con_coop

* Renta de la propiedad
gen double rent_prop =interes+alquiler+otras_ren+dividendos+alq_inm+alq_tierras 

* Tranferencias
gen double trans_t=trans_nogob+trans_gob  

* Ingreso total
gen double IC_total=remu_asala+rent_empre+rent_prop+trans_t 
recode IC_total (.=0)
* Suma de ingresos
tabstat remu_asala rent_empre trans_t IC_total, stat(sum) format(%22.2fc)

* Depuración de la base de datos
keep  folio numren edad paren1 parentesco IC_total
sort  folio numren IC_total
order folio numren IC_total

* Identifica el máximo ingreso individual dentro de los hogares
bysort folio: egen double ing_max_h = max(IC_total) 

* Identifica al miembro con el mayor ingreso dentro del hogar
gen prov_econ = (IC_total == ing_max_h)

* Parentesco del sosten económico
gen paren_sosten = parentesco if prov_econ == 1
tab paren_sosten
recode paren_sosten   /// 
       (101 102=1)    /// Jefe del hogar
	   (200/205=2)    /// Conyuge
	   (300/305=3)    /// Hijos
	   (500/700=999)  // Otros parentescos 

* Tabulado del sosten económico según parentesco
tab paren_sosten

* Identifica el parentesco del sosten económico a nivel vivienda
bysort folio: egen paren_sosten_h = max(paren_sosten)

* Identifica conyuge a nivel de hogar
gen conyuge = (paren1 == 2)
bysort folio: egen conyuge_h = max(conyuge)

* Identifica hijo a nivel de hogar
gen hijo = (paren1 == 3)
bysort folio: egen hijo_h = max(hijo)

* Identifica nuera o yerno a nivel de hogar
gen ny = (parentesco == 617)
bysort folio: egen ny_h = max(ny)

* Menores de 12 años
gen menores12 = 1 if edad >= 0 & edad <= 12
recode menores12 (.=0)
label var menores12 "Menores de 12 años"

* Hogares con menores de 12 años
egen menores12_h = sum(menores12), by(folio)
recode menores12_h (1/20 = 1)
tab menores12_h
label var menores12_h "Menores de 12 años en el hogar"

*************************************************
* Principal sosten: jefe del hogar (JH)
*************************************************

* Con menores de 12 años en hogar & conyuge del JH
gen prelacion_jh = .
replace prelacion_jh = 1 if paren_sosten_h == 1 & paren1==1                                                       // JH sosten & parentesco JH
replace prelacion_jh = 2 if paren_sosten_h == 1 & paren1==2 & menores12_h==1                                      // JH sosten & parentesco conyuge
replace prelacion_jh = 3 if paren_sosten_h == 1 & (edad >= 14 & edad <=  17) & conyuge_h==1 & prelacion_jh == .   // JH sosten & adolescentes (14 a 17)
replace prelacion_jh = 4 if paren_sosten_h == 1 & (edad >=  0 & edad <=  13) & conyuge_h==1 & prelacion_jh == .   // JH sosten & menores (0 a 13)
replace prelacion_jh = 5 if paren_sosten_h == 1 & (edad >= 18 & edad <= 140) & conyuge_h==1 & prelacion_jh == .   // JH sosten & mayores 18

* Sin menores de 12 años en hogar
replace prelacion_jh = 3 if paren_sosten_h == 1 & (edad >= 14 & edad <=  17) & prelacion_jh == .  // JH sosten & adolescentes (14 a 17)
replace prelacion_jh = 4 if paren_sosten_h == 1 & (edad >=  0 & edad <=  13) & prelacion_jh == .  // JH sosten & menores (0 a 13)
replace prelacion_jh = 5 if paren_sosten_h == 1 & (edad >= 18 & edad <= 140) & prelacion_jh == .  // JH sosten & mayores 18

*************************************************
* Principal sosten:  hijo del JH
*************************************************

* Se asume que todos los nietos del jefe del hogar son del hijo
* Con menores de 12 años en hogar & conyuge del JH
gen prelacion_hijo = .
replace prelacion_hijo = 1 if paren_sosten_h == 3 & paren1==3 & (IC_total==ing_max_h)                           // Hijo del JH sosten & parentesco Hijo
replace prelacion_hijo = 2 if paren_sosten_h == 3 & paren1==7 & menores12_h==1                                  // Hijo del JH sosten & parentesco nuera/yerno
replace prelacion_hijo = 3 if paren_sosten_h == 3 & (edad >= 14 & edad <=  17) & ny_h==1 & prelacion_hijo == .  // Hijo del JH sosten & adolescentes (14 a 17)
replace prelacion_hijo = 4 if paren_sosten_h == 3 & (edad >=  0 & edad <=  13) & ny_h==1 & prelacion_hijo == .  // Hijo del JH sosten & menores (0 a 13)
replace prelacion_hijo = 5 if paren_sosten_h == 3 & (edad >= 18 & edad <= 140) & ny_h==1 & prelacion_hijo == .  // Hijo del JH sosten & mayores 18

* Sin menores de 12 años en hogar
replace prelacion_hijo = 3 if paren_sosten_h == 3 & (edad >= 14 & edad <=  17) & prelacion_hijo == .  // Hijo del JH sosten & adolescentes (14 a 17)
replace prelacion_hijo = 4 if paren_sosten_h == 3 & (edad >=  0 & edad <=  13) & prelacion_hijo == .  // Hijo del JH sosten & menores (0 a 13)
replace prelacion_hijo = 5 if paren_sosten_h == 3 & (edad >= 18 & edad <= 140) & prelacion_hijo == .  // Hijo del JH sosten & mayores 18

*************************************************
* Principal sosten: conyuge del JH
*************************************************

* Con y sin menores de 12 años en hogar 
gen prelacion_c = .
replace prelacion_c = 1 if paren_sosten_h == 2 & paren1==2 & (IC_total==ing_max_h)                // Conyuge del JH sosten
replace prelacion_c = 2 if paren_sosten_h == 2 & paren1==1 & menores12_h==1                       // JH (esposo del conyuge)
replace prelacion_c = 3 if paren_sosten_h == 2 & (edad >= 14 & edad <=  17) & prelacion_c == .    // Conyuge del JH sosten & adolescentes (14 a 17)
replace prelacion_c = 4 if paren_sosten_h == 2 & (edad >=  0 & edad <=  13) & prelacion_c == .    // Conyuge del JH sosten & menores (0 a 13)
replace prelacion_c = 5 if paren_sosten_h == 2 & (edad >= 18 & edad <= 140) & prelacion_c == .    // Conyuge del JH sosten & mayores 18

*************************************************
* Principal sosten: otros parentescos
*************************************************

gen prelacion_otros = .
replace prelacion_otros = 1 if paren_sosten_h == 999 & (IC_total==ing_max_h)                               // Otro parentesco sosten
replace prelacion_otros = 3 if paren_sosten_h == 999 & (edad >= 14 & edad <=  17) & prelacion_otros == .   // Otro parentesco & adolescentes (14 a 17)
replace prelacion_otros = 4 if paren_sosten_h == 999 & (edad >=  0 & edad <=  13) & prelacion_otros == .   // Otro parentesco & menores (0 a 13)
replace prelacion_otros = 5 if paren_sosten_h == 999 & (edad >= 18 & edad <= 140) & prelacion_otros == .   // Otro parentesco & mayores 18

recode prelacion_jh prelacion_hijo prelacion_c prelacion_otros (.=0)

* Genera variable de prelación
gen prelacion = max(prelacion_jh, prelacion_hijo, prelacion_c, prelacion_otros)

* Depuración de la base de datos
keep folio numren prelacion parentesco
label variable prelacion   "Orden de prioridad según ingreso y presencia de menores de edad"

* Guardar base 
save "$bases/prelacion.dta", replace 








